==> huaweicloudsdkdataartsstudio-3.1.140-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_security_data_categories_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSecurityDataCategoriesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'category_groups': 'list[DataCategoryDTO]'
    }

    attribute_map = {
        'total': 'total',
        'category_groups': 'category_groups'
    }

    def __init__(self, total=None, category_groups=None):
        """ListSecurityDataCategoriesResponse

        The model defined in huaweicloud sdk

        :param total: 数据分类总的数量
        :type total: int
        :param category_groups: 数据分类列表
        :type category_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.DataCategoryDTO`]
        """
        
        super(ListSecurityDataCategoriesResponse, self).__init__()

        self._total = None
        self._category_groups = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if category_groups is not None:
            self.category_groups = category_groups

    @property
    def total(self):
        """Gets the total of this ListSecurityDataCategoriesResponse.

        数据分类总的数量

        :return: The total of this ListSecurityDataCategoriesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListSecurityDataCategoriesResponse.

        数据分类总的数量

        :param total: The total of this ListSecurityDataCategoriesResponse.
        :type total: int
        """
        self._total = total

    @property
    def category_groups(self):
        """Gets the category_groups of this ListSecurityDataCategoriesResponse.

        数据分类列表

        :return: The category_groups of this ListSecurityDataCategoriesResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.DataCategoryDTO`]
        """
        return self._category_groups

    @category_groups.setter
    def category_groups(self, category_groups):
        """Sets the category_groups of this ListSecurityDataCategoriesResponse.

        数据分类列表

        :param category_groups: The category_groups of this ListSecurityDataCategoriesResponse.
        :type category_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.DataCategoryDTO`]
        """
        self._category_groups = category_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSecurityDataCategoriesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_security_data_categories_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSecurityDataCategoriesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'category_groups': 'list[DataCategoryDTO]'
    }

    attribute_map = {
        'total': 'total',
        'category_groups': 'category_groups'
    }

    def __init__(self, total=None, category_groups=None):
        r"""ListSecurityDataCategoriesResponse

        The model defined in huaweicloud sdk

        :param total: 数据分类总的数量
        :type total: int
        :param category_groups: 数据分类列表
        :type category_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.DataCategoryDTO`]
        """
        
        super(ListSecurityDataCategoriesResponse, self).__init__()

        self._total = None
        self._category_groups = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if category_groups is not None:
            self.category_groups = category_groups

    @property
    def total(self):
        r"""Gets the total of this ListSecurityDataCategoriesResponse.

        数据分类总的数量

        :return: The total of this ListSecurityDataCategoriesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListSecurityDataCategoriesResponse.

        数据分类总的数量

        :param total: The total of this ListSecurityDataCategoriesResponse.
        :type total: int
        """
        self._total = total

    @property
    def category_groups(self):
        r"""Gets the category_groups of this ListSecurityDataCategoriesResponse.

        数据分类列表

        :return: The category_groups of this ListSecurityDataCategoriesResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.DataCategoryDTO`]
        """
        return self._category_groups

    @category_groups.setter
    def category_groups(self, category_groups):
        r"""Sets the category_groups of this ListSecurityDataCategoriesResponse.

        数据分类列表

        :param category_groups: The category_groups of this ListSecurityDataCategoriesResponse.
        :type category_groups: list[:class:`huaweicloudsdkdataartsstudio.v1.DataCategoryDTO`]
        """
        self._category_groups = category_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSecurityDataCategoriesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
